@@ -8,23 +8,42 @@ use Carp;
 use PerlIO::gzip;
 use Lingua::YALI;
 
-our $VERSION = '0.010_02'; # VERSION
+our $VERSION = '0.010_03'; # VERSION
+
+# hash with paths to models
+# format: { 'class1' => 'file1', 'class2' => 'file2' }
+has '_model_file' => ( 
+    is => 'rw', 
+    isa => 'HashRef' 
+    );
+
+# hash with n-gram frequencies retrieved from models
+# format: { 'ngram1' => { 'class1' => 0.5, 'class2' => 0.3}, 'ngram2' => ...}
+has '_frequency' => ( 
+    is => 'rw', 
+    isa => 'HashRef' 
+    );
+
+# n-gram size
+has '_ngram' => ( 
+    is => 'rw', 
+    isa => 'Int' 
+    );
+
+# list of identified classes
+has '_classes' =>  ( 
+    is => 'rw', 
+    isa => 'ArrayRef' 
+    );
 
-has '_model_file' => ( is => 'rw', isa => 'HashRef' );
-has '_frequency' => ( is => 'rw', isa => 'HashRef' );
-has '_models_loaded' => ( is => 'rw', isa => 'HashRef' );
-has '_ngram' => ( is => 'rw', isa => 'Int' );
-has '_classes' =>  ( is => 'rw', isa => 'ArrayRef' );
 
 
 sub BUILD
 {
     my $self = shift;
     my %frequency = ();
-    my %models_loaded = ();
     my @classes = ();
     $self->{_frequency} = \%frequency;
-    $self->{_models_loaded} = \%models_loaded;
     $self->{_classes} = \@classes;
 
     return;
@@ -39,6 +58,7 @@ sub add_class
         return 0;
     }
 
+    # parameter check
     if ( ! defined($file) ) {
         croak("Model has to be specified.");
     }
@@ -66,6 +86,7 @@ sub remove_class
     return 0;
 }
 
+
 sub get_classes
 {
     my $self    = shift;
@@ -195,7 +216,7 @@ sub _load_model
 {
     my ($self, $class, $file) = @_;
 
-    if ( $self->{_models_loaded}->{$class} ) {
+    if ( $self->{_model_file}->{$class} ) {
         return;
     }
 
@@ -228,7 +249,6 @@ sub _load_model
 
     close($fh);
 
-    $self->{_models_loaded}->{$class} = 1;
     $self->{_model_file}->{$class} = $file;
     $self->_compute_classes();   
 
@@ -239,11 +259,10 @@ sub _unload_model
 {
     my ($self, $class) = @_;
 
-    if ( ! $self->{_models_loaded}->{$class} ) {
+    if ( ! $self->{_model_file}->{$class} ) {
         return;
     }
 
-    delete($self->{_models_loaded}->{$class});
     delete( $self->{_model_file}->{$class} );   
     $self->_compute_classes();
 
@@ -272,17 +291,18 @@ Lingua::YALI::Identifier - Module for language identification with custom models
 
 =head1 VERSION
 
-version 0.010_02
+version 0.010_03
 
 =head1 SYNOPSIS
 
-This modul is generalizatin of L<Lingua::YALI::LanguageIdentifier|Lingua::YALI::LanguageIdentifier> and can identify
-any document class based on used models.
+This modul identify languages with moduls provided by the user. If you want to use pretrained models use L<Lingua::YALI::LanguageIdentifier|Lingua::YALI::LanguageIdentifier>.
+
+Models trained on texts from specific domain outperforms the general ones.
 
     use Lingua::YALI::Builder;
     use Lingua::YALI::Identifier;
     
-    // create models
+    # create models
     my $builder_a = Lingua::YALI::Builder->new(ngrams=>[2]);
     $builder_a->train_string("aaaaa aaaa aaa aaa aaa aaaaa aa");
     $builder_a->store("model_a.2_all.gz", 2);
@@ -291,19 +311,19 @@ any document class based on used models.
     $builder_b->train_string("bbbbbb bbbb bbbb bbb bbbb bbbb bbb");
     $builder_b->store("model_b.2_all.gz", 2);
 
-    // create identifier and load models
+    # create identifier and load models
     my $identifier = Lingua::YALI::Identifier->new();
     $identifier->add_class("a", "model_a.2_all.gz");
     $identifier->add_class("b", "model_b.2_all.gz");
 
-    // identify strings
+    # identify strings
     my $result1 = $identifier->identify_string("aaaaaaaaaaaaaaaaaaa");
     print $result1->[0]->[0] . "\t" . $result1->[0]->[1];
-    // prints out a 1
+    # prints out a 1
     
     my $result2 = $identifier->identify_string("bbbbbbbbbbbbbbbbbbb");
     print $result2->[0]->[0] . "\t" . $result2->[0]->[1];
-    // prints out b 1
+    # prints out b 1
 
 More examples is presented in L<Lingua::YALI::Examples|Lingua::YALI::Examples>.
 
@@ -313,32 +333,32 @@ More examples is presented in L<Lingua::YALI::Examples|Lingua::YALI::Examples>.
 
 Initializes internal variables.
 
-    // create identifier
+    # create identifier
     my $identifier = Lingua::YALI::Identifier->new();
 
 =head2 add_class
 
-    $added = $identifier->add_class($label, $model)
+    $added = $identifier->add_class($class, $model)
 
-Adds model stored in file C<$model> with label C<$label> and
+Adds model stored in file C<$model> with class C<$class> and
 returns whether it was added or not.
 
     print $identifier->add_class("a", "model.a1.gz") . "\n"; 
-    // prints out 1
+    # prints out 1
     print $identifier->add_class("a", "model.a2.gz") . "\n";
-    // prints out 0 - class a was already added
+    # prints out 0 - class a was already added
 
 =head2 remove_class
 
      my $removed = $identifier->remove_class($class);
 
-Removes model for label $label.
+Removes model for class C<$class>.
 
     $identifier->add_class("a", "model.a1.gz");
     print $identifier->remove_class("a") . "\n"; 
-    // prints out 1
+    # prints out 1
     print $identifier->remove_class("a") . "\n";
-    // prints out 0 - class a was already removed     
+    # prints out 0 - class a was already removed     
 
 =head2 get_classes
 
@@ -401,6 +421,8 @@ according to score descendently, so the most probable class is the first.
 
 =item * Builder for these models is L<Lingua::YALI::Builder|Lingua::YALI::Builder>.
 
+=item * There is also command line tool L<yali-identifier|Lingua::YALI::yali-identifier> with similar functionality.
+
 =item * Source codes are available at L<https://github.com/martin-majlis/YALI>.
 
 =back
